
use lib "$ENV{ANTELOPE}/data/perl" ;
use Datascope ;
use sysinfo ; 

sub setpath {
    my @old = split(':', $ENV{PATH} ) ; 
    my %path ; 
    foreach (@old) { 
	$path{$_} = 1 ; 
    }
    my (@new) ;
    foreach (qw(/usr/bin /usr/sbin /sbin /bin /etc /usr/local/bin /opt/local/bin /usr/local/sbin /opt/local/sbin /opt/sfw/bin /usr/sfw/bin /usr/proc/bin /usr/ccs/bin /usr/X11R6/bin /usr/X11/bin /usr/openwin/bin /usr/dt/bin)) { 
	if ( (-d $_ || -l $_) && ! defined $path{$_} ) { 
	    push(@new, $_) ; 
	}
    }
    $::ENV{PATH} .= ":" . join(':', @new) if @new > 0 ; 
}

sub snapshot_name {
    my ($name) = @_ ; 
    $name = $name . "-" . &epoch2str(time(), "%A_%B_%d_%H.%M.%S")  ;
    return $name ; 
}

sub setup_snapshot {
    my ($name, @dirs) = @_ ;
    my ( $output, $stagedir, $subdir, $logfile ) ;
    $stage = "/var/tmp" ;
    $subdir = snapshot_name($name) ;
    $tmpdir = "$stage/$subdir" ;
    mkdir $tmpdir, 0755 || die "couldn't create directory $tmpdir for data" ;
    foreach my $dir ( @dirs ) {
        mkdir "$tmpdir/$dir", 0755 || die "couldn't create directory $tmpdir/$dir" ;
    }
    $log = "$tmpdir/snapshot-$name" ;
    open (LOG, ">$log" ) ;
    use IO::Handle;
    LOG->autoflush(1);
    return ($stage, $subdir, $log) ;
}

sub run {
    my ( $cmd ) = @_ ;
    print STDOUT "$cmd\n" if $opt_v ;
    print LOG "\n> $cmd\n" ;
    open (CMD, "-|", "$cmd 2>&1" ) ;
    @cmd = <CMD> ;
    close CMD ;
    $result = $? ;
    print LOG "@cmd" ;
    if ( $result == 0xff00 ) {
        print LOG "\n  *** command failed ** \n" ;
    } elsif ( $result > 0x80 ) {
        my $exit = $result>>8 ;
        printf LOG "\n  *** exit status %x ** \n", $exit ;
    }
}

sub syssnap { 
    my ( $LOGMAX ) = @_ ; 
    $LOGMAX = 200 if ! defined $LOGMAX ; 
    print LOG "\nSystem Configuration\n" ;
    my $antelope = $ENV{'ANTELOPE'} ;
    printf LOG "> ANTELOPE=$antelope" ;
    &run ( "uname -a" ) ;
    &run ( "env" ) ;
    my @files = (</etc/*-version>,</etc/*-release>) ;
    foreach (@files) {
	open (IN, $_) ;
	@in = <IN> ;
	print LOG "$_\n" ;
	printf LOG "    %s\n", join("    ", @in ) ;
	close IN ;
    }
    &run ( "ifconfig -a" ) ;
    &run ( "pwd" ) ;
    &run ( "date" ) ;
    &run ( "df -kl" ) ;
    &run ( "who" ) ;
    &run ( "id" ) ;
    &run ( "find . ! -perm -200 -ls" ) ;
    &run ( "ls $antelope/patched" ) ;
    &run ( "csh -c limit" ) ;
    &run ( "cat $antelope/data/pf/license.pf" ) ;
    chomp(my $os = `uname -s`) ;
    if ( $os eq "SunOS" ) {
	&run ( "/usr/sbin/prtconf -p" ) ;
	&run ( "/usr/sbin/prtconf -D" ) ;
	&run ( "/usr/sbin/prtconf -V" ) ;
	&run ( "/bin/showrev -a" ) ;
	&run ( "tail -$LOGMAX /var/adm/messages " ) ;
	&run ( "tail -$LOGMAX /var/log/syslog" ) ;
	&run ( "top -d 3 -s 3 -n $LOGMAX || prstat -n 20 1 2" ) ;
	&run ( "swap -s " ) ;
    } elsif ( $os eq "Linux" ) {
	&run ( "tail -$LOGMAX /var/log/messages " ) ;
	&run("cat /proc/meminfo" ) ;
	&run("cat /proc/swaps" ) ;
	&run ( "top -d 3 -s 3 -n $LOGMAX" ) ;
    } elsif ( $os eq "Darwin" ) {
	&run ( "/usr/bin/top -u -l 3 -s 3 -n $LOGMAX" ) ;
	&run ( "tail -$LOGMAX /var/log/netinfo.log" ) ;
    } else {
	print LOG "\n*** Don't know how to get system log and swap information for $
    os\n\n" ;
    }
    &run ( "last -10 reboot" ) ;
    &run ( "ls -FC ." ) ;
    &run ( "ntptrace" ) ;
}


1;
